@@ -23,6 +23,7 @@ from typing import (
 
 from smartparams.cli import Print, parse_arguments
 from smartparams.io import load_data, print_data, save_data
+from smartparams.options import Option
 from smartparams.utils import (
     check_key_is_in,
     check_missings,
@@ -30,21 +31,21 @@ from smartparams.utils import (
     check_typings,
     convert_to_primitive_types,
     flatten_keys,
-    get_class_name,
     get_nested_dictionary_and_key,
-    import_class,
-    join_classes,
+    get_object_name,
+    import_callable,
     join_keys,
-    parse_class,
+    join_objects,
+    parse_object,
     parse_param,
     remove_duplicated_key_and_value,
     str_to_bool,
 )
 
-_T = TypeVar('_T')
+T = TypeVar('T')
 
 
-class Smart(Generic[_T]):
+class Smart(Generic[T]):
     """Creates a partial wrapper for a class that can be configurable from a file or a cli.
 
     Smart class has functionality of both partial and dict classes. It allows creating
@@ -120,19 +121,19 @@ class Smart(Generic[_T]):
 
     def __init__(
         self,
-        _type: Type[Union[_T, Dict]] = dict,
+        _class: Callable[..., T] = cast(Callable[..., T], dict),
         /,
         **kwargs: Any,
     ) -> None:
         """Creates instance of Smart class.
 
         Args:
-            _type: Class to be wrapped.
+            _class: Class to be wrapped.
             **kwargs: Partial keyword arguments to be passed to the class constructor.
 
         """
-        self._type: Type[Union[_T, Dict]] = _type
-        self._dict: Dict[str, Any] = dict()
+        self._class: Callable[..., T] = _class
+        self._params: Dict[str, Any] = dict()
 
         self._location: str = ''
 
@@ -140,18 +141,18 @@ class Smart(Generic[_T]):
             self.set(k, v)
 
     @property
-    def type(self) -> Type[Union[_T, Dict]]:
-        return self._type
+    def type(self) -> Callable[..., T]:
+        return self._class
 
     @property
     def dict(self) -> Dict[str, Any]:
-        return self._dict.copy()
+        return self._params.copy()
 
     def __call__(
         self,
         *args: Any,
         **kwargs: Any,
-    ) -> _T:
+    ) -> T:
         """Creates instance of given type.
 
         Args:
@@ -163,31 +164,34 @@ class Smart(Generic[_T]):
 
         """
         params = self._init_dict(
-            dictionary=self._dict,
+            dictionary=self._params,
             location=self._location,
         )
 
+        callable_name = join_objects(self._location, get_object_name(self._class))
+
         if self.check_overrides:
             check_overrides(
-                location=join_classes(self._location, get_class_name(self._type)),
                 params=params,
                 kwargs=kwargs,
+                callable_name=callable_name,
                 raise_error=self.strict,
             )
 
         params.update(kwargs)
 
-        return self._init_class(
+        return self._instantiate(
             location=self._location,
-            cls=self._type,
+            callable_name=callable_name,
+            callable_=self._class,
             args=args,
             kwargs=params,
         )
 
     def __str__(self) -> str:
-        cls_str = "" if self._type is dict else f"[{get_class_name(self._type)}]"
-        params_str = ", ".join((f"{k}={v}" for k, v in self._dict.items()))
-        return f"{self.__class__.__name__}{cls_str}({params_str})"
+        class_string = "" if self._class is dict else f"[{get_object_name(self._class)}]"
+        params_string = ", ".join((f"{k}={v}" for k, v in self._params.items()))
+        return f"{self.__class__.__name__}{class_string}({params_string})"
 
     def __repr__(self) -> str:
         return str(self)
@@ -207,7 +211,7 @@ class Smart(Generic[_T]):
             Keys from dictionary.
 
         """
-        keys = flatten_keys(self._dict) if flatten else self._dict
+        keys = flatten_keys(self._params) if flatten else self._params
         if pattern is None:
             yield from keys
         else:
@@ -260,7 +264,7 @@ class Smart(Generic[_T]):
             True if name is in dictionary, otherwise False.
 
         """
-        return check_key_is_in(name, self._dict)
+        return check_key_is_in(name, self._params)
 
     def get(
         self,
@@ -281,7 +285,7 @@ class Smart(Generic[_T]):
 
         """
         dictionary, key = get_nested_dictionary_and_key(
-            dictionary=self._dict,
+            dictionary=self._params,
             name=name,
             required=default is ...,
         )
@@ -303,7 +307,7 @@ class Smart(Generic[_T]):
 
         """
         dictionary, key = get_nested_dictionary_and_key(
-            dictionary=self._dict,
+            dictionary=self._params,
             name=name,
             set_mode=True,
         )
@@ -329,7 +333,7 @@ class Smart(Generic[_T]):
 
         """
         dictionary, key = get_nested_dictionary_and_key(
-            dictionary=self._dict,
+            dictionary=self._params,
             name=name,
             required=default is ...,
         )
@@ -354,7 +358,7 @@ class Smart(Generic[_T]):
 
         """
         dictionary, key = get_nested_dictionary_and_key(
-            dictionary=self._dict,
+            dictionary=self._params,
             name=name,
             required=True,
         )
@@ -447,13 +451,19 @@ class Smart(Generic[_T]):
             Object of instantiated class.
 
         """
-        obj = self._init_object(
-            obj=self.dict if name is None else self.get(name),
-            location=self._location,
-        )
+        if name is None:
+            obj = self._init_object(
+                obj=self.dict,
+                location=self._location,
+            )
+        else:
+            obj = self._init_object(
+                obj=self.get(name),
+                location=join_keys(self._location, name),
+            )
 
-        if persist and name is not None:
-            return self.set(name, obj)
+            if persist:
+                return self.set(name, obj)
 
         return obj
 
@@ -479,7 +489,7 @@ class Smart(Generic[_T]):
 
         smart.update_from(
             source=self._object_representation(
-                obj=self._type,
+                obj=self._class,
                 skip_default=skip_defaults,
             ),
             override=False,
@@ -490,16 +500,17 @@ class Smart(Generic[_T]):
             missing_value=self.missing_value,
         )
 
+    @classmethod
     def register(
-        self,
+        cls,
         classes: Union[
-            Sequence[Union[str, Type[Any]]],
+            Sequence[Union[str, Callable]],
             Mapping[str, str],
-            Mapping[Type[Any], str],
-            Mapping[Union[str, Type[Any]], str],
+            Mapping[Callable, str],
+            Mapping[Union[str, Callable], str],
         ],
         prefix: str = '',
-    ) -> 'Smart':
+    ) -> Type['Smart']:
         """Registers classes to be imported.
 
         Args:
@@ -510,30 +521,25 @@ class Smart(Generic[_T]):
             Smart object.
 
         """
-        if self._location:
-            raise AttributeError(
-                f"Classes can only be registered in root Smart object, not in {self._location}."
-            )
-
         if isinstance(classes, Sequence):
-            self._register_classes(
+            cls._register_classes(
                 classes=classes,
                 prefix=prefix,
             )
         elif isinstance(classes, Mapping):
-            self._register_aliases(
+            cls._register_aliases(
                 aliases=classes,
                 prefix=prefix,
             )
         else:
             raise TypeError(f"Register classes type '{type(classes)}' is not supported.")
 
-        return self
+        return cls
 
     def run(
         self,
-        function: Callable[['Smart'], Any],
-        path: Path = Path('params.yaml'),
+        function: Optional[Callable[['Smart'], Any]] = None,
+        path: Optional[Path] = None,
     ) -> 'Smart':
         """Runs main function.
 
@@ -545,17 +551,22 @@ class Smart(Generic[_T]):
             Smart object.
 
         """
-        args = parse_arguments(default_path=path)
+        args = parse_arguments(
+            default_path=path,
+        )
 
         if args.strict:
             Smart.strict = True
 
-        if args.path.is_file():
+        if args.path:
             self.update_from(args.path)
 
         self.update_from(args.params)
 
         if args.dump:
+            if not args.path:
+                raise ValueError("Cannot dump params if path is not specified.")
+
             save_data(
                 data=self.representation(
                     skip_defaults=args.skip_defaults,
@@ -579,15 +590,21 @@ class Smart(Generic[_T]):
                 )
             else:
                 raise NotImplementedError(f"Print '{args.print}' has not been implemented yet.")
+        elif function is None:
+            self()
         else:
             function(self)
 
         return self
 
-    def _init_object(self, obj: Any, location: str) -> Any:
+    def _init_object(
+        self,
+        obj: Any,
+        location: str,
+    ) -> Any:
         if isinstance(obj, dict):
             if self.keyword in obj:
-                return self._init_class_from_dict(
+                return self._instantiate_from_dict(
                     dictionary=obj,
                     location=location,
                 )
@@ -605,7 +622,11 @@ class Smart(Generic[_T]):
 
         return obj
 
-    def _init_dict(self, dictionary: Dict[str, Any], location: str) -> Dict[str, Any]:
+    def _init_dict(
+        self,
+        dictionary: Dict[str, Any],
+        location: str,
+    ) -> Dict[str, Any]:
         return {
             key: self._init_object(
                 obj=value,
@@ -614,7 +635,11 @@ class Smart(Generic[_T]):
             for key, value in dictionary.items()
         }
 
-    def _init_list(self, lst: List[Any], location: str) -> List[Any]:
+    def _init_list(
+        self,
+        lst: List[Any],
+        location: str,
+    ) -> List[Any]:
         return [
             self._init_object(
                 obj=element,
@@ -623,84 +648,94 @@ class Smart(Generic[_T]):
             for index, element in enumerate(lst)
         ]
 
-    def _init_class_from_dict(
+    def _instantiate_from_dict(
         self,
         dictionary: Dict[str, Any],
         location: str,
     ) -> Any:
-        kwargs, class_name, option = parse_class(
+        kwargs, name, option = parse_object(
             dictionary=dictionary,
             keyword=self.keyword,
         )
 
-        if class_name == self.__class__.__name__:
-            return self._init_class(
+        if name == self.__class__.__name__:
+            return self._instantiate(
                 location=location,
-                cls=Smart,
+                callable_name=join_objects(location, self.__class__.__name__),
+                callable_=Smart,
                 kwargs=kwargs,
             )
 
-        if class_name in self._origins:
-            class_name = self._origins[class_name]
+        if name in self._origins:
+            name = self._origins[name]
         elif self.allow_only_registered_classes:
-            raise ImportError(f"Class '{class_name}' is not registered.")
+            raise ImportError(f"Class '{name}' is not registered.")
 
-        cls = cast(Type[_T], import_class(class_name))
+        callable_ = import_callable(name)
+        callable_name = join_objects(location, get_object_name(callable_))
 
         if option:
-            if option == self.__class__.__name__:
-                return self._init_class(
+            if option == Option.SMART:
+                return self._instantiate(
                     location=location,
-                    cls=Smart,
-                    args=(cls,),
+                    callable_name=callable_name,
+                    callable_=Smart,
+                    args=(callable_,),
                     kwargs=kwargs,
                 )
 
+            if option == Option.TYPE:
+                if kwargs:
+                    raise ValueError(f"Cannot specify any arguments for {callable_name}'s type.")
+
+                return callable_
+
             raise ValueError(f"Option '{option}' is not supported.")
 
-        return self._init_class(
+        return self._instantiate(
             location=location,
-            cls=cls,
+            callable_name=callable_name,
+            callable_=callable_,
             kwargs=kwargs,
         )
 
-    def _init_class(
+    def _instantiate(
         self,
         location: str,
-        cls: Type[Any],
+        callable_name: str,
+        callable_: Callable,
         args: Optional[Tuple[Any, ...]] = None,
         kwargs: Optional[Dict[str, Any]] = None,
     ) -> Any:
-        class_location = join_classes(location, get_class_name(cls))
         args = args or tuple()
         kwargs = kwargs or dict()
 
         if self.check_missings:
             check_missings(
-                location=class_location,
                 kwargs=kwargs,
                 missing_value=self.missing_value,
+                callable_name=callable_name,
                 raise_error=self.strict,
             )
 
         if self.check_typings:
             check_typings(
-                cls=cls,
+                callable_=callable_,
                 args=args,
                 kwargs=kwargs,
-                location=class_location,
+                callable_name=callable_name,
                 raise_error=self.strict,
             )
 
         try:
-            obj = cls(*args, **kwargs)
+            callable_ = callable_(*args, **kwargs)
         except Exception as e:
-            raise RuntimeError(f"Error during instantiate {class_location} class.") from e
+            raise RuntimeError(f"Error during instantiate '{callable_name}'.") from e
         else:
-            if isinstance(obj, Smart):
-                obj._location = location
+            if isinstance(callable_, Smart):
+                callable_._location = location
 
-            return obj
+            return callable_
 
     def _object_representation(
         self,
@@ -710,14 +745,16 @@ class Smart(Generic[_T]):
         representation: Dict[str, Any] = dict()
         signature = inspect.signature(obj)
 
-        for name, param in signature.parameters.items():
-            if name != 'self' and param.kind in (
-                inspect.Parameter.POSITIONAL_OR_KEYWORD,
-                inspect.Parameter.KEYWORD_ONLY,
-            ):
-                annotation = param.annotation
-                default = param.default
+        for i, param in enumerate(signature.parameters.values()):
+            name = param.name
+            kind = param.kind
+            annotation = param.annotation
+            default = param.default
 
+            if not (i == 0 and annotation is param.empty and default is param.empty) or kind in (
+                param.POSITIONAL_OR_KEYWORD,
+                param.KEYWORD_ONLY,
+            ):
                 if annotation is Smart or isinstance(default, Smart) and default.type is dict:
                     representation[name] = {
                         self.keyword: self.__class__.__name__,
@@ -730,7 +767,7 @@ class Smart(Generic[_T]):
 
                     keyword = inspect.formatannotation(param_type)
                     keyword = self._aliases.get(keyword, keyword)
-                    keyword = join_classes(keyword, get_class_name(self))
+                    keyword = join_objects(keyword, Option.SMART.value)
 
                     representation[name] = {
                         self.keyword: keyword,
@@ -739,11 +776,11 @@ class Smart(Generic[_T]):
                             skip_default=skip_default,
                         ),
                     }
-                elif default is not inspect.Parameter.empty and skip_default:
+                elif default is not param.empty and skip_default:
                     continue
                 elif default is None or isinstance(default, (bool, float, int, str)):
                     representation[name] = default
-                elif annotation is not inspect.Parameter.empty and isinstance(annotation, type):
+                elif annotation is not param.empty and isinstance(annotation, type):
                     if annotation in (bool, float, int, str):
                         representation[name] = annotation.__name__ + self.missing_value
                     else:
@@ -761,22 +798,24 @@ class Smart(Generic[_T]):
 
         return representation
 
+    @classmethod
     def _register_classes(
-        self,
-        classes: Sequence[Union[str, Type[Any]]],
+        cls,
+        classes: Sequence[Union[str, Callable]],
         prefix: str = '',
     ) -> None:
-        self._register_aliases(
-            aliases={cls: cls if isinstance(cls, str) else get_class_name(cls) for cls in classes},
+        cls._register_aliases(
+            aliases={c: c if isinstance(c, str) else get_object_name(c) for c in classes},
             prefix=prefix,
         )
 
+    @classmethod
     def _register_aliases(
-        self,
+        cls,
         aliases: Union[
             Mapping[str, str],
-            Mapping[Type[Any], str],
-            Mapping[Union[str, Type[Any]], str],
+            Mapping[Callable, str],
+            Mapping[Union[str, Callable], str],
         ],
         prefix: str = '',
     ) -> None:
@@ -786,19 +825,19 @@ class Smart(Generic[_T]):
 
             remove_duplicated_key_and_value(
                 key=origin,
-                key_dict=self._aliases,
-                value_dict=self._origins,
+                key_dict=cls._aliases,
+                value_dict=cls._origins,
                 message=f"Origin '{origin}' has been overridden.",
-                raise_error=self.strict,
+                raise_error=cls.strict,
             )
 
             remove_duplicated_key_and_value(
                 key=alias,
-                key_dict=self._origins,
-                value_dict=self._aliases,
+                key_dict=cls._origins,
+                value_dict=cls._aliases,
                 message=f"Alias '{alias}' has been overridden.",
-                raise_error=self.strict,
+                raise_error=cls.strict,
             )
 
-            self._aliases[origin] = alias
-            self._origins[alias] = origin
+            cls._aliases[origin] = alias
+            cls._origins[alias] = origin
