@@ -2,12 +2,22 @@ import inspect
 import json
 import warnings
 from pydoc import locate
-from typing import Any, Dict, List, Mapping, Optional, Sequence, Tuple, Type, get_origin
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    List,
+    Mapping,
+    Optional,
+    Sequence,
+    Tuple,
+    get_origin,
+)
 
 from typeguard import check_type
 
 _KEY_SEPARATOR = '.'
-_CLASS_SEPARATOR = ':'
+_OBJECT_SEPARATOR = ':'
 _PARAM_SEPARATOR = '='
 
 
@@ -97,18 +107,18 @@ def join_keys(*args: str) -> str:
     return _KEY_SEPARATOR.join(a for a in args if a)
 
 
-def join_classes(*args: str) -> str:
-    return _CLASS_SEPARATOR.join(a for a in args if a)
+def join_objects(*args: str) -> str:
+    return _OBJECT_SEPARATOR.join(a for a in args if a)
 
 
-def parse_class(
+def parse_object(
     dictionary: Dict[str, Any],
     keyword: str,
 ) -> Tuple[Dict[str, Any], str, Optional[str]]:
     kwargs = dictionary.copy()
-    class_name = kwargs.pop(keyword)
-    class_name, _, option = class_name.partition(_CLASS_SEPARATOR)
-    return kwargs, class_name, option
+    name = kwargs.pop(keyword)
+    name, _, option = name.partition(_OBJECT_SEPARATOR)
+    return kwargs, name, option
 
 
 def parse_param(param: str) -> Tuple[str, Any]:
@@ -136,16 +146,16 @@ def str_to_bool(value: str) -> bool:
     raise ValueError(f"String value '{value}' is not like to boolean.")
 
 
-def import_class(name: str) -> type:
-    cls = locate(name)
-    if cls is None:
-        raise ValueError(f"Class '{name}' does not exist.")
-    if not isinstance(cls, type):
-        raise ValueError(f"Object '{name}' is not a class.")
-    return cls
+def import_callable(name: str) -> Callable:
+    obj = locate(name)
+    if obj is None:
+        raise ValueError(f"Object '{name}' does not exist.")
+    if not callable(obj):
+        raise ValueError(f"Object '{name}' is not callable.")
+    return obj
 
 
-def get_class_name(obj: Any) -> str:
+def get_object_name(obj: Any) -> str:
     try:
         return obj.__qualname__
     except AttributeError:
@@ -173,53 +183,53 @@ def get_type_hints(signature: inspect.Signature) -> Dict[str, Any]:
 
 
 def check_overrides(
-    location: str,
     params: Dict[str, Any],
     kwargs: Dict[str, Any],
+    callable_name: str,
     raise_error: bool,
 ) -> None:
     if overrides := set(params).intersection(kwargs):
-        msg = f"Override {location}'s class arguments {overrides}."
+        msg = f"Override {callable_name}'s arguments {overrides}."
         if raise_error:
             raise ValueError(msg)
         warnings.warn(msg)
 
 
 def check_missings(
-    location: str,
     kwargs: Dict[str, Any],
     missing_value: str,
+    callable_name: str,
     raise_error: bool,
 ) -> None:
     for name, value in kwargs.items():
         if isinstance(value, str) and value.endswith(missing_value):
-            msg = f"Missing {location}'s class argument '{name}' value."
+            msg = f"Missing {callable_name}'s argument '{name}' value."
             if raise_error:
                 raise ValueError(msg)
             warnings.warn(msg)
 
 
 def check_typings(
-    location: str,
-    cls: Type[Any],
+    callable_: Callable,
     args: Tuple[Any, ...],
     kwargs: Dict[str, Any],
+    callable_name: str,
     raise_error: bool,
 ) -> None:
-    if cls is dict:
+    if callable_ is dict:
         return None
 
-    signature = inspect.signature(cls)
+    signature = inspect.signature(callable_)
     try:
         arguments = signature.bind(*args, **kwargs).arguments
     except TypeError as e:
-        raise TypeError(f"The {location}'s class {''.join(e.args)}.")
+        raise TypeError(f"The {callable_name}'s {''.join(e.args)}.")
 
     for name, expected_type in get_type_hints(signature).items():
         if name in arguments:
             try:
                 check_type(
-                    argname=f"{location}'s class argument '{name}'",
+                    argname=f"{callable_name}'s argument '{name}'",
                     value=arguments[name],
                     expected_type=expected_type,
                 )
