@@ -1,7 +1,9 @@
 import os
 import unittest
 
-_INTEGRATION = bool(int(os.getenv('TEST_INTEGRATION', default='0')))
+from smartparams.utils import str_to_bool
+
+_INTEGRATION = str_to_bool(os.getenv('TEST_INTEGRATION', default='1'))
 
 
 @unittest.skipUnless(_INTEGRATION, reason="Integration tests are disabled")
