@@ -1,7 +1,9 @@
 import os
 import unittest
 
-_UNIT = bool(int(os.getenv('TEST_UNIT', default='1')))
+from smartparams.utils import str_to_bool
+
+_UNIT = str_to_bool(os.getenv('TEST_UNIT', default='1'))
 
 
 @unittest.skipUnless(_UNIT, reason="Unit tests are disabled")
