@@ -16,7 +16,7 @@ class TestSmartInitCase(UnitCase):
         params = self.smart.dict
 
         self.assertEqual(dict(arg1='arg1', arg2=10), params)
-        self.assertIsNot(self.smart._dict, params)
+        self.assertIsNot(self.smart._params, params)
 
     def test_call(self) -> None:
         obj = self.smart()
@@ -202,11 +202,18 @@ class TestSmartInstantiateCase(UnitCase):
         self.params = dict(
             smart_dict={'class': 'Smart'},
             smart={'class': self.class_name + ':Smart', 'arg1': 'arg1', 'arg2': 10},
+            type={'class': self.class_name + ':Type'},
             object={'class': self.class_name, 'arg1': 'arg1', 'arg2': 10},
             value=21,
         )
         self.smart: Smart = Smart(**self.params)
 
+    def test_init(self) -> None:
+        obj = self.smart.init()
+
+        self.assertIsInstance(obj, dict)
+        self.assertEqual(('smart_dict', 'smart', 'type', 'object', 'value'), tuple(obj.keys()))
+
     def test_init__persist(self) -> None:
         obj = self.smart.init('object')
 
@@ -222,72 +229,57 @@ class TestSmartInstantiateCase(UnitCase):
         self.assertTrue('object' in self.smart.dict)
 
     def test_init__any(self) -> None:
-        data = "string"
+        result = self.smart.init('value')
 
-        result = self.smart._init_object(data, '')
-
-        self.assertEqual(data, result)
+        self.assertEqual(21, result)
 
     def test_init__smart_dict(self) -> None:
-        obj = self.params['smart_dict']
-
-        result = self.smart._init_object(obj, '')
+        result = self.smart.init('smart_dict')
 
         self.assertIsInstance(result, Smart)
         self.assertIs(result.type, dict)
 
     def test_init__smart(self) -> None:
-        obj = self.params['smart']
-
-        result = self.smart._init_object(obj, '')
+        result = self.smart.init('smart')
 
         self.assertIsInstance(result, Smart)
         self.assertIs(result.type, Class)
 
-    def test_init__unknown(self) -> None:
-        obj = self.params['smart']
-        obj['class'] += "suffix"  # type: ignore
+    def test_init__type(self) -> None:
+        result = self.smart.init('type')
 
-        self.assertRaises(ValueError, self.smart._init_object, obj, '')
+        self.assertIs(result, Class)
+
+    def test_init__type__raises(self) -> None:
+        self.smart.set('type.argument', 10)
+
+        self.assertRaises(ValueError, self.smart.init, 'type')
+
+    def test_init__unknown(self) -> None:
+        self.smart.map('smart.class', lambda x: x + 'suffix')
+
+        self.assertRaises(ValueError, self.smart.init, 'smart')
 
     def test_init__object(self) -> None:
-        obj = self.params['object']
-
-        result = self.smart._init_object(obj, '')
+        result = self.smart.init('object')
 
         self.assertIsInstance(result, Class)
 
-    def test_init__dict(self) -> None:
-        obj = {'key': 'value'}
-
-        result = self.smart._init_object(obj, '')
-
-        self.assertIsNot(obj, result)
-
-    def test_init__list(self) -> None:
-        obj = ['item']
-
-        result = self.smart._init_object(obj, '')
-
-        self.assertIsNot(obj, result)
-
     def test_init__with_aliases(self) -> None:
         self.smart.allow_only_registered_classes = True
         self.smart._aliases = {self.class_name: 'Class'}
         self.smart._origins = {v: k for k, v in self.smart._aliases.items()}
-        obj = self.params['object']
-        obj['class'] = 'Class'  # type: ignore
+        self.smart.set('object.class', 'Class')
 
-        result = self.smart._init_object(obj, '')
+        result = self.smart.init('object')
 
         self.assertIsInstance(result, Class)
 
     def test_init__with_aliases_not_used(self) -> None:
         self.smart._aliases = {self.class_name: 'Class'}
         self.smart._origins = {v: k for k, v in self.smart._aliases.items()}
-        obj = self.params['object']
 
-        result = self.smart._init_object(obj, '')
+        result = self.smart.init('object')
 
         self.assertIsInstance(result, Class)
 
@@ -295,19 +287,18 @@ class TestSmartInstantiateCase(UnitCase):
         self.smart.allow_only_registered_classes = True
         self.smart._aliases = {self.class_name: 'Class'}
         self.smart._origins = {v: k for k, v in self.smart._aliases.items()}
-        obj = self.params['object']
 
-        self.assertRaises(ImportError, self.smart._init_object, obj, '')
+        self.assertRaises(ImportError, self.smart.init, 'object')
 
 
 class TestRegisterCase(UnitCase):
     def setUp(self) -> None:
-        self.smart: Smart = Smart()
+        self.smart = Smart
         self.smart.strict = True
 
     def tearDown(self) -> None:
-        Smart._aliases = dict()
-        Smart._origins = dict()
+        self.smart._aliases = dict()
+        self.smart._origins = dict()
 
     def test_register__classes(self) -> None:
         classes = ('origin.1', 'origin.2')
@@ -373,8 +364,3 @@ class TestRegisterCase(UnitCase):
 
     def test_register__raise(self) -> None:
         self.assertRaises(TypeError, self.smart.register, Mock())
-
-    def test_register__nested(self) -> None:
-        self.smart._location = 'nested'
-
-        self.assertRaises(AttributeError, self.smart.register, Mock())
