@@ -5,8 +5,8 @@ from unittest.mock import Mock
 from smartparams import Smart
 from smartparams.utils import (
     convert_to_primitive_types,
-    get_class_name,
     get_nested_dictionary_and_key,
+    get_object_name,
     get_type_hints,
     parse_param,
     str_to_bool,
@@ -100,21 +100,21 @@ class TestParseParam(UnitCase):
         self.assertRaises(ValueError, parse_param, data)
 
 
-class TestGetClassName(UnitCase):
-    def test_get_class_name(self) -> None:
+class TestGetObjectName(UnitCase):
+    def test(self) -> None:
         test_cases = (
             (Mock, 'Mock'),
             (Mock(), 'Mock'),
             (123, 'int'),
             (type, 'type'),
             (None, 'NoneType'),
-            (lambda: ..., 'TestGetClassName.test_get_class_name.<locals>.<lambda>'),
-            ((i for i in range(1)), 'TestGetClassName.test_get_class_name.<locals>.<genexpr>'),
+            (lambda: ..., 'TestGetObjectName.test.<locals>.<lambda>'),
+            ((i for i in range(1)), 'TestGetObjectName.test.<locals>.<genexpr>'),
         )
 
         for cls, expected in test_cases:
             with self.subTest(expected=expected):
-                actual = get_class_name(cls)  # type: ignore
+                actual = get_object_name(cls)  # type: ignore
 
                 self.assertEqual(expected, actual)
 
